@@ -5,10 +5,10 @@ from random import sample
 import networkx as nx
 import yaml
 
-from adb import list_packages, uninstall_pkg, install_pkg
-from AddUserCase import AddUserCase
-from dbsql import sql2key, sql2dict
-from page import name2short, img_path, ope2num
+from seleniumqt.adb import list_packages, uninstall_pkg, install_pkg
+from seleniumqt.AddUserCase import AddUserCase
+from seleniumqt.dbsql import sql2key, sql2dict
+from seleniumqt.page import name2short, img_path, ope2num
 
 
 def manual_case(add_case_list):
